import { ILine } from "../types";
/**
 * Computes the intersection point between the two given lines, if it exists.
 *
 * Finds the location at which the first and second line meet. If the lines are parallel and not overlapping,
 * this function returns no intersection. If the lines are completely overlapping,
 * this function returns the first line's initial point.
 *
 * The returned value is an {@link IPointIntersectionResult} object which will have have the
 * `exists` flag set to `true` iff an intersection was found. It additionally
 * has the following fields, if the intersection exists:
 *
 * - `x` – the x-coordinate of the point of intersection
 * - `y` – the y-coordinate of the point of intersection
 * - `t0` – where along the first line's geometry the intersection was found,
 *      according to the first line's parameterization
 * - `t1` – where along the second line's geometry the intersection was found,
 *      according to the second line's parameterization
 *
 * @param a the first line to intersect
 * @param b the second line to find intersection with
 * @param out
 * @see {@link lineIntersectPolylineIterator}
 * @see {@link lineIntersectRay}
 * @see {@link lineIntersectSegment}
 */
export declare function lineIntersectLine(a: ILine, b: ILine, out?: import("../types").IPointIntersectionResult): import("../types").IPointIntersectionResult;
