import { ILine, IMat2d } from "../types";
/**
 * Transforms a line by an affine matrix.
 *
 * This function computes the result of applying a transform to the line's geometry.
 * The resulting initial point will be the result of applying the given transform to the original
 * initial point, and its direction will be the result of applying any rotations or shears from
 * the matrix. The resulting direction vector will be correctly normalized when applicable.
 *
 * Affine transformations and their specifics within Math2d are described in more detail
 * in the {@link vecTransformBy} docs.
 *
 * Synonymous to {@link rayTransformBy}.
 *
 * @param line the line to transform
 * @param mat the affine transform to apply
 * @param out
 * @see {@link vecTransformBy}
 * @see {@link Imat2d}
 */
export declare function lineTransformBy(line: ILine, mat: IMat2d, out?: ILine): ILine;
