var Mat2d = /** @class */ (function () {
    function Mat2d(a, b, c, d, e, f) {
        if (a === void 0) { a = NaN; }
        if (b === void 0) { b = NaN; }
        if (c === void 0) { c = NaN; }
        if (d === void 0) { d = NaN; }
        if (e === void 0) { e = NaN; }
        if (f === void 0) { f = NaN; }
        this.a = a;
        this.b = b;
        this.c = c;
        this.d = d;
        this.e = e;
        this.f = f;
    }
    return Mat2d;
}());
/**
 * Creates a new mat2d object in memory, with all values initialized to `NaN`.
 *
 * Data allocation functions like `mat2dAlloc()` are useful to hold results of
 * Math2d function calls in inner loops of performance critical workflows.
 *
 * As with any optimization, you don't need it until you've profiled your
 * application! Getting into temp variable management and shared state can
 * severely hurt code readability and maintainability, so it's best to avoid
 * such optimization if you can.
 *
 * @example
 *  // initialize temp memory
 *  const TMP0 = mat2dAlloc();
 *
 *  ... {
 *    // Use this temp memory to hold result of `mat2dInvert()`.
 *    // This avoids a heap allocation.
 *    const result = mat2dInvert(existingObj.transform, TMP0);
 *  }
 */
export function mat2dAlloc() {
    return new Mat2d();
}
