var Ray = /** @class */ (function () {
    function Ray(x0, y0, dirX, dirY) {
        if (x0 === void 0) { x0 = NaN; }
        if (y0 === void 0) { y0 = NaN; }
        if (dirX === void 0) { dirX = NaN; }
        if (dirY === void 0) { dirY = NaN; }
        this.x0 = x0;
        this.y0 = y0;
        this.dirX = dirX;
        this.dirY = dirY;
    }
    return Ray;
}());
/**
 * Creates a new Ray object in memory, with all values initialized to `NaN`.
 *
 * Data allocation functions like `rayAlloc()` are useful to hold results of
 * Math2d function calls in inner loops of performance critical workflows.
 *
 * As with any optimization, you don't need it until you've profiled your
 * application! Getting into temp variable management and shared state can
 * severely hurt code readability and maintainability, so it's best to avoid
 * such optimization if you can.
 *
 * @example
 *  // initialize temp memory
 *  const TMP0 = rayAlloc();
 *
 *  ... {
 *    // Use this temp memory to hold result of `rayLookAt()`.
 *    // This avoids a heap allocation.
 *    const result = rayLookAt(existingObj.source, existingObj.target, TMP0);
 *  }
 */
export function rayAlloc() {
    return new Ray();
}
