var Segment = /** @class */ (function () {
    function Segment(x0, y0, x1, y1) {
        if (x0 === void 0) { x0 = NaN; }
        if (y0 === void 0) { y0 = NaN; }
        if (x1 === void 0) { x1 = NaN; }
        if (y1 === void 0) { y1 = NaN; }
        this.x0 = x0;
        this.y0 = y0;
        this.x1 = x1;
        this.y1 = y1;
    }
    return Segment;
}());
/**
 * Creates a new Segment object in memory, with all values initialized to `NaN`.
 *
 * Data allocation functions like `segmentAlloc()` are useful to hold results of
 * Math2d function calls in inner loops of performance critical workflows.
 *
 * As with any optimization, you don't need it until you've profiled your
 * application! Getting into temp variable management and shared state can
 * severely hurt code readability and maintainability, so it's best to avoid
 * such optimization if you can.
 *
 * @example
 *  // initialize temp memory
 *  const TMP0 = segmentAlloc();
 *
 *  ... {
 *    // Use this temp memory to hold result of `polygonGetSideSegment()`.
 *    // This avoids a heap allocation.
 *    const result = polygonGetSideSegment(existingObj.geometry, 0, TMP0);
 *  }
 */
export function segmentAlloc() {
    return new Segment();
}
