import { ISegment } from "../types";
/**
 * Gets a point along the line segment, parameterized according to linear interpolation
 * between its endpoints.
 *
 * A segment is parameterized according to linear interpolation between its endpoints,
 * where _t_ = 0 represents its starting vertex and _t_ = 1 its ending vertex.
 * Smooth values of _t_ within that range will move along the segment, so for example
 * _t_ = 0.5 is its midpoint.
 *
 * This function does allow for _t_ values outside the range `[0, 1]`, which will return
 * points in the same direction as the segment but outside in either direction.
 *
 * @param segment the segment to inspect
 * @param t linear ratio along the segment to return
 * @param out
 * @see {@link ISegment}
 * @see {@link vecLerp}
 */
export declare function segmentGetPointAt(segment: ISegment, t: number, out?: import("../types").IVec): import("../types").IVec;
