import { _lerp } from "../internal/_lerp";
import { EPSILON_SQ } from "../internal/const";
import { nearestPointResultAlloc } from "../nearestPointResultFunctions/nearestPointResultAlloc";
import { nearestPointResultReset } from "../nearestPointResultFunctions/nearestPointResultReset";
import { vecAlloc } from "../vecFunctions/vecAlloc";
import { vecCross } from "../vecFunctions/vecCross";
import { vecDot } from "../vecFunctions/vecDot";
import { vecGetLengthSq } from "../vecFunctions/vecGetLengthSq";
import { vecReset } from "../vecFunctions/vecReset";
var TMP0 = vecAlloc();
var TMP1 = vecAlloc();
/**
 * Finds the closest the segment comes to a given reference point.
 *
 * This function returns the squared euclidean distance in the `distanceValue` field of the result.
 *
 * @param segment segment to inspect
 * @param point point to measure squared distance to
 * @param out
 * @see {@link ISegment}
 * @see {@link INearestPointResult}
 */
export function segmentNearestDistanceSqToPoint(segment, point, out) {
    if (out === void 0) { out = nearestPointResultAlloc(); }
    var segVector = vecReset(segment.x1 - segment.x0, segment.y1 - segment.y0, TMP0);
    var pointVector = vecReset(point.x - segment.x0, point.y - segment.y0, TMP1);
    var segLengthSq = vecGetLengthSq(segVector);
    if (segLengthSq < EPSILON_SQ) {
        return nearestPointResultReset(segment.x0, segment.y0, 0, vecGetLengthSq(pointVector), out);
    }
    var dot = vecDot(pointVector, segVector);
    if (dot < 0) {
        return nearestPointResultReset(segment.x0, segment.y0, 0, vecGetLengthSq(pointVector));
    }
    else if (dot > segLengthSq) {
        var dx = point.x - segment.x1;
        var dy = point.y - segment.y1;
        return nearestPointResultReset(segment.x1, segment.y1, 1, dx * dx + dy * dy);
    }
    else {
        var perp = vecCross(segVector, pointVector);
        var distanceSq = (perp * perp) / segLengthSq;
        var t = dot / segLengthSq;
        return nearestPointResultReset(_lerp(segment.x0, segment.x1, t), _lerp(segment.y0, segment.y1, t), t, distanceSq);
    }
}
