var Vec = /** @class */ (function () {
    function Vec(x, y) {
        if (x === void 0) { x = NaN; }
        if (y === void 0) { y = NaN; }
        this.x = x;
        this.y = y;
    }
    return Vec;
}());
/**
 * Creates a new Vec object in memory, with all values initialized to `NaN`.
 *
 * Data allocation functions like `vecAlloc()` are useful to hold results of
 * Math2d function calls in inner loops of performance critical workflows.
 *
 * As with any optimization, you don't need it until you've profiled your
 * application! Getting into temp variable management and shared state can
 * severely hurt code readability and maintainability, so it's best to avoid
 * such optimization if you can.
 *
 * @example
 *  // initialize temp memory
 *  const TMP0 = vecAlloc();
 *
 *  ... {
 *    // Use this temp memory to hold result of `vecNormalize()`.
 *    // This avoids a heap allocation.
 *    const result = vecNormalize(existingObj.velocity, TMP0);
 *  }
 */
export function vecAlloc() {
    return new Vec();
}
